@@ -41,7 +41,9 @@ def get_result(job_id):
 
 
 def parse_result(result):
-    all_results = dict([res.split() for res in result.split('>') if res])
+    # split results and remove newlines from sequence
+    all_results = [res.partition('\n') for res in result.split('>') if res]
+    all_results = {k: v.replace('\n', '') for (k, _, v) in all_results}
     # anything non-structured (marked by a `-`) is disordered
     modes = ('jnetpred', 'JNETSOL25', 'JNETSOL5', 'JNETSOL0', 'JNETHMM', 'JNETPSSM')
     df = pd.DataFrame({f'jpred_{mode}': [data == '-' for data in all_results[mode]] for mode in modes})
