@@ -1,5 +1,5 @@
 from .submission import retry, JobNotDone, ensure_and_log
 from .parsing import csv2frame, frame_from_ranges, parse_disembl_globplot, parse_fasta
 from .formatting import pre_format_result
-from .io import write_csv, write_dscore, read_dscore
+from .io import write_csv, write_score, read_dscore
 from .plotting import dscore_plot, servers_plot, consensus_plot
